# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# PROJECT TITLE:  SCALA COVID PROFILE ANALYSES
# CODE AUTHOR:    JAKOB MANTHEY
# DATE STARTED:   2 JUNE 2021

# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# 1) ESSENTIALS
# ______________________________________________________________________________________________________________________

# clean workspace
rm(list=ls())

# set working directory
setwd("C:/Data.work/Publications/JoGH_scala covid paper/revision")

# current date:
DATE <- 211216

# load libraries
library( data.table )
library( openxlsx )
library( ggplot2 )
library( lme4 )
library( lubridate )
library( stringr )


# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# color vectors:
# 2 group comparisons
c2Panel_a <- c('#081C48', '#9C8014')
c2Panel_b <- c('#442918', '#A5634D')
colors2 <- c("#2b8cbe","#a6bddb")

# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# 2) LOAD DATA
# ______________________________________________________________________________________________________________________

# 2.1) ALCOHOL DATA
# ----------------------------------------------

input1 <- data.table(read.xlsx("covid alcohol profile_data_revision.xlsx", sheet = "alc data", detectDates = T))
alc.dat <- copy(input1)
str(alc.dat$date.tally)
alc.dat$sex.pat.lab <- factor(alc.dat$sex.pat.lab, levels = c("women","men","other / not reported"))
alc.dat$edu.lab <- factor(alc.dat$edu.lab, levels = c("Less than high school","High school","Any education beyond high school","not reported"))
alc.dat$age.pat.cat <- factor(alc.dat$age.pat.cat, levels = c("(15,29]","(29,39]","(39,49]","(49,59]","(59,69]","(69,99]"))
alc.dat$prof.lab <- factor(alc.dat$prof.lab, levels = c("Doctor", "Midwife or social worker","Nurse (technician)","Psychologist","Other / not reported"))
alc.dat$age.prov.cat <- factor(alc.dat$age.prov.cat, levels = c("(15,29]","(29,39]","(39,49]","(49,59]","(59,69]","(69,99]"))
alc.dat$sex.prov.lab <- factor(alc.dat$sex.prov.lab, levels = c("women","men"))

# 2.2) ALCOHOL DATA - aggregated for each day
# ----------------------------------------------

input2 <- data.table(read.xlsx("covid alcohol profile_data.xlsx", sheet = "aggregated day", detectDates = T))
day.dat <- copy(input2)
str(day.dat$date.tally)


# 2.3) ALCOHOL DATA - aggregated for each month
# ----------------------------------------------

input3 <- data.table(read.xlsx("covid alcohol profile_data.xlsx", sheet = "aggregated month", detectDates = T))
month.dat <- copy(input3)


# 2.4) START OF COVID PERIODS IN COUNTRIES
# ----------------------------------------------

covid.col <- as.Date("2020-03-17")
covid.mex <- as.Date("2020-03-23")


# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# 3) DESCRIPTIVE ANALYSES
# ______________________________________________________________________________________________________________________

# 3.1) INTRO
# ----------------------------------------------

# number of PHCCs
length(unique(alc.dat$phcc.id)) ## 34

# 3.2) METHODS
# ----------------------------------------------

# number of providers participating:
length(unique(alc.dat$prov.id)) ## 220

# time:
alc.dat[, min(date.tally)] # 20 August 2019
alc.dat[, max(date.tally)] # 30 April 2021

# 3.3) DESCRIPTIVES
# ----------------------------------------------

# period of no data collection in COL
alc.dat[iso == "COL" & date.tally < as.Date("2020-05-15"), max(date.tally)] # 19 March 2020
alc.dat[iso == "COL" & date.tally > as.Date("2020-05-15"), min(date.tally)] # 20 August 2020

as.Date("2020-03-20") - as.Date("2020-08-19") #152 days
152/7 ## 22 weeks

# number of alcohol assessments in how many days?
nrow(alc.dat[audit.any == T]) # 17273
nrow(alc.dat[iso == "COL" & audit.any == T]) # 10659
nrow(alc.dat[iso == "MEX" & audit.any == T]) # 6614

alc.dat[iso == "COL", min(date.tally)] # 20 August 2019
alc.dat[iso == "COL", max(date.tally)] # 30 April 2021

as.Date("2021-04-30") - as.Date("2019-08-20") #619 days

alc.dat[iso == "MEX", min(date.tally)] # 9 September 2019
alc.dat[iso == "MEX", max(date.tally)] # 30 April 2021

as.Date("2021-04-30") - as.Date("2019-09-06") #602 days


# 3.4) ALCOHOL MANAGEMENT
# ----------------------------------------------

##  Alcohol measurement
#   ..................

##  DESCRIPTIVE CHANGE
alc.dat[, mean(auditc.sum, na.rm = T), by = .(iso,period)]
alc.dat[!is.na(auditc.sum), .(t.test(auditc.sum)$estimate, 
                             t.test(auditc.sum)$conf.int[1],
                             t.test(auditc.sum)$conf.int[2]), by = .(iso,period)]

##  AUDIT - C distribution
#   ..................

hist(alc.dat$auditc.sum) 
hist(log(alc.dat$auditc.sum))

# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# 4) GLMMs - MAIN ANALYSES
# ______________________________________________________________________________________________________________________

# 4.1) DV1: AUDIT-C sum score
# ----------------------------------------------

##  DESCRIPTIVE CHANGE
alc.dat[!is.na(auditc.sum), .(t.test(auditc.sum)$estimate, 
                              t.test(auditc.sum)$conf.int[1],
                              t.test(auditc.sum)$conf.int[2]), by = .(iso,period)]

# COL
col.model.1d   <- glmer.nb(auditc.sum ~ month + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                            (1 | phcc.id/prov.id), data = alc.dat[iso == "COL" & !is.na(auditc.sum)])
summary(col.model.1d) # ok

col.model.1e   <- glmer.nb(auditc.sum ~ period + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                             (1 | phcc.id/prov.id), data = alc.dat[iso == "COL" & !is.na(auditc.sum)])
summary(col.model.1e) # ok


# MEX
mex.model.1d   <- glmer.nb(auditc.sum ~ month + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                            (1 | phcc.id/prov.id), data = alc.dat[iso == "MEX" & !is.na(auditc.sum)])
summary(mex.model.1d) # ok


mex.model.1f   <- glmer.nb(auditc.sum ~ period + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                          (1 | phcc.id/prov.id), data = alc.dat[iso == "MEX" & !is.na(auditc.sum)], control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=1e5)))
summary(mex.model.1f) # ok


# 4.2) DV2: % risky drinker
# ----------------------------------------------

##  DESCRIPTIVE CHANGE
alc.dat[!is.na(auditc.risk), .(1 - prop.test(table(auditc.risk))$estimate, 
                              1 - prop.test(table(auditc.risk))$conf.int[2],
                              1 - prop.test(table(auditc.risk))$conf.int[1]), by = .(iso,period)]
# COL
col.model.2d   <- glmer(auditc.risk ~ month + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                          (1 | prov.id), data = alc.dat[iso == "COL" & !is.na(auditc.risk) & prof.lab != "Other / not reported"], family = binomial(),
                        control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
summary(col.model.2d)

col.model.2e   <- glmer(auditc.risk ~ period + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                          (1 | prov.id), data = alc.dat[iso == "COL" & !is.na(auditc.risk) & prof.lab != "Other / not reported"], family = binomial(),
                        control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
summary(col.model.2e)



# MEX
mex.model.2e   <- glmer(auditc.risk ~ month + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                          (1 | prov.id), data = alc.dat[iso == "MEX" & !is.na(auditc.risk) & sex.pat.lab != "other / not reported" & prof.lab != "Midwife or social worker"], family = binomial(),
                        control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
summary(mex.model.2e)

mex.model.2f   <- glmer(auditc.risk ~ period + sex.prov.lab + age.prov.cat + prof.lab + sex.pat.lab + age.pat.cat + edu.lab + 
                          (1 | prov.id), data = alc.dat[iso == "MEX" & !is.na(auditc.risk) & sex.pat.lab != "other / not reported" & prof.lab != "Midwife or social worker"], family = binomial(),
                        control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
summary(mex.model.2f)




# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

save.image(file = paste0("R workspace_",DATE,".Rdata"))

# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# 5) TABLES
# ______________________________________________________________________________________________________________________

setwd("C:/Data.work/Publications/JoGH_scala covid paper")

# 5.1) TABLE 1
# ----------------------------------------------
## Provider characteristics
alc.dat.un <- unique(copy(alc.dat[,.(iso, period, prov.id, sex.prov.lab, age.prov.cat, prof.lab)]), by = "prov.id")

# N
alc.dat.un[, table(iso,period)]

# Proportions with 95% confidence interval
library(freqtables)
library(dplyr)
Table1.1 <- function(x,y){
  a <- alc.dat.un[iso == x & period == y] %>% freq_table(sex.prov.lab) %>% freq_format(recipe = "percent% (lcl-ucl)", name = "95% CI", digits = 1) %>% select(cat, '95% CI')
  b <- alc.dat.un[iso == x & period == y] %>% freq_table(age.prov.cat) %>% freq_format(recipe = "percent% (lcl-ucl)", name = "95% CI", digits = 1) %>% select(cat, '95% CI')
  c <- alc.dat.un[iso == x & period == y] %>% freq_table(prof.lab) %>% freq_format(recipe = "percent% (lcl-ucl)", name = "95% CI", digits = 1) %>% select(cat, '95% CI')
  list <- list(sex = a, age = b, profession = c)
  return(list)
}
isos <- c("COL", "MEX")
lapply(isos, Table1.1, 0)
lapply(isos, Table1.1, 1)

## Patient characteristics

# N
alc.dat[, table(iso,period)]

# Proportions with 95% confidence interval
Table1.2 <- function(x,y){
  a <- alc.dat[iso == x & period == y] %>% freq_table(sex.pat.lab) %>% freq_format(recipe = "percent% (lcl-ucl)", name = "95% CI", digits = 1)  %>% select(cat, '95% CI')
  b <- alc.dat[iso == x & period == y] %>% freq_table(age.pat.cat) %>% freq_format(recipe = "percent% (lcl-ucl)", name = "95% CI", digits = 1) %>% select(cat, '95% CI')
  c <- alc.dat[iso == x & period == y] %>% freq_table(edu.lab) %>% freq_format(recipe = "percent% (lcl-ucl)", name = "95% CI", digits = 1) %>% select(cat, '95% CI')
  list <- list(sex = a, age = b, education = c)
  return(list)
}
lapply(isos, Table1.2, 0)
lapply(isos, Table1.2, 1)

# Chi-square and independent t-tests

alc.dat[iso == "COL", chisq.test(sex.pat.lab, period)]
alc.dat[iso == "MEX", chisq.test(sex.pat.lab, period)]

alc.dat[iso == "COL", chisq.test(age.pat.cat, period)]
alc.dat[iso == "MEX", chisq.test(age.pat.cat, period)]

alc.dat[iso == "COL", chisq.test(education, period, simulate.p.value = TRUE)]
alc.dat[iso == "MEX", chisq.test(education, period, simulate.p.value = TRUE)]

alc.dat[iso == "COL", chisq.test(education, period)]
alc.dat[iso == "MEX", chisq.test(education, period)]

alc.dat[iso == "COL", t.test(age.pat ~ period)]
alc.dat[iso == "MEX", t.test(age.pat ~ period)]

detach("package:freqtables", unload=TRUE)
detach("package:dplyr", unload=TRUE)

alc.dat[, length(unique(date.tally)), by = .(iso, period)]

# 1.2) TABLE 2
# ----------------------------------------------

#model.in <- copy(col.model.1d)
Table2 <- function(model.in){
  
  options(scipen = 999)
  # get coef table
  tab.dat <- data.table(var.name = row.names(summary(model.in)$coef), coef(summary(model.in)))
  names(tab.dat) <- c("var.name", "coef","se","zval","pval")
  order.var <- unique(tab.dat$var.name)
  order.var
  
  
  # add Wald CIs
  add <- data.table(var.name = row.names(confint(model.in, method="Wald")), confint(model.in, method="Wald"))
  names(add) <- c("var.name", "lower","upper")
  tab.dat <- merge(tab.dat, add, by = c("var.name"), all.x = T)
  tab.dat$var.name <- factor(tab.dat$var.name, levels = order.var, ordered = T)
  tab.dat <- tab.dat[order(var.name)]
  
  # exp:
  tab.dat[, ':=' (coef.exp = exp(coef),
                  lower.exp = exp(lower),
                  upper.exp = exp(upper))]
  
  # stars:
  tab.dat[, stars := ifelse(pval<.001, "***", 
                            ifelse(pval<.01, "**", 
                                   ifelse(pval<.05, "*", "")))]
  
  # combine in 1
  tab.dat[, ':=' (val1 = format(coef.exp, digits = 3),
                  val2 = format(lower.exp, digits = 3),
                  val3 = format(upper.exp, digits = 3))]
  tab.dat[, out := paste0(val1, " (", val2, " to ", val3, ")", stars)]
  
  # check:
  tab.dat[var.name == "month"]
  
  # return
  return(tab.dat[,.(var.name,out)])
  
}

# out:
##  Trend
out <- Table2(col.model.1d)
write.csv(out, paste0("outputs/",DATE,"/Table_2_A1_COL.csv"), row.names = F)
out <- Table2(mex.model.1d)
write.csv(out, paste0("outputs/",DATE,"/Table_2_A1_MEX.csv"), row.names = F)
out <- Table2(col.model.2d)
write.csv(out, paste0("outputs/",DATE,"/Table_2_B1_COL.csv"), row.names = F)
out <- Table2(mex.model.2e)
write.csv(out, paste0("outputs/",DATE,"/Table_2_B1_MEX.csv"), row.names = F)

##  Effect
out <- Table2(col.model.1e)
write.csv(out, paste0("outputs/",DATE,"/Table_2_A2_COL.csv"), row.names = F)
out <- Table2(mex.model.1f)
write.csv(out, paste0("outputs/",DATE,"/Table_2_A2_MEX.csv"), row.names = F)
out <- Table2(col.model.2e)
write.csv(out, paste0("outputs/",DATE,"/Table_2_B2_COL.csv"), row.names = F)
out <- Table2(mex.model.2f)
write.csv(out, paste0("outputs/",DATE,"/Table_2_B2_MEX.csv"), row.names = F)




# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# 5) FIGURES
# ______________________________________________________________________________________________________________________

# 5.1) FIGURE 1: trends in alcohol profile
# ----------------------------------------------

pdat <- copy(day.dat)
pdat[, vertical := ifelse(iso == "COL", covid.col, covid.mex)]

coeff1 <- max(pdat$auditc.risk, na.rm = T)
coeff2 <- max(pdat$auditc.sum.mean, na.rm = T)

ggplot(pdat, aes(x = date.tally)) + 
  theme_bw() + facet_grid(country ~ ., scales = "free") + 
  ggtitle("Changes in the alcohol consumption profile in primary health care patients",
          "Data collected in Colombia and Mexico") +
  geom_bar(aes(y = auditc.risk / coeff1 * coeff2), fill = c2Panel_a[2], stat = "identity", alpha = 0.5) +  
  geom_point(aes(y = auditc.sum.mean), color = c2Panel_a[1], alpha = 0.4) +
  geom_smooth(aes(y = auditc.risk / coeff1 * coeff2), color = c2Panel_a[2]) +
  geom_smooth(aes(y = auditc.sum.mean), color = c2Panel_a[1]) + 
  geom_vline(aes(xintercept = vertical), linetype = 2) +
  scale_x_date(name = "", date_labels = "%b/%Y", date_breaks = "2 months") +
  scale_y_continuous(name = "Mean AUDIT-C sum score", limits = c(0,7.5),
                     sec.axis = sec_axis(~.*coeff1/coeff2, name="% of patients scoring 8+ on AUDIT-C")) +
  theme(axis.text.x = element_text(angle = 45, vjust =0.5, hjust=0.5),
        strip.background = element_rect(fill="white"))

ggsave(paste0("outputs/",DATE,"/Figure_1.png"), width = 8, height = 5)
ggsave(paste0("outputs/",DATE,"/Figure_1_1200dpi.tiff"), width = 8, height = 5, dpi = 1200)
ggsave(paste0("outputs/",DATE,"/Figure_1.tiff"), width = 8, height = 5, dpi = 1200)



# 5.2) FIGURE 2: Mean AUDIT-C by country - sex age and period
# ----------------------------------------------

alc.dat[, table(age.pat,age.pat.cat)]
pdat <- copy(alc.dat[!is.na(auditc.sum) & !is.na(age.pat.cat) & sex.pat.lab != "other / not reported",.(iso,period,auditc.sum,sex = sex.pat.lab,age = age.pat.cat)])
pdat[, country := ifelse(iso == "COL", "Colombia", "Mexico")]
pdat$period.lab <- factor(pdat$period, labels = c("0" = "before COVID", "1" = "during COVID"))

add1 <- pdat[, .(.N, age = "All",
                 mean = t.test(auditc.sum)$estimate,
                 lower = t.test(auditc.sum)$conf.int[1],
                 upper = t.test(auditc.sum)$conf.int[2]), by = .(iso,country,period,period.lab,sex)] 
add2 <- pdat[, .(.N, 
                 mean = t.test(auditc.sum)$estimate,
                 lower = t.test(auditc.sum)$conf.int[1],
                 upper = t.test(auditc.sum)$conf.int[2]), by = .(iso,country,period,period.lab,sex,age)]

pdat <- rbind(add1,add2)
pdat[, age := ifelse(age %like% "\\(15,29]", "18-29",
                     ifelse(age %like% "\\(29,39]", "30-39",
                            ifelse(age %like% "\\(39,49]", "40-49",
                                   ifelse(age %like% "\\(49,59]", "50-59",
                                          ifelse(age %like% "\\(59,69]", "60-69",
                                                 ifelse(age %like% "\\(69,99]", "70+",
                                                        ifelse(age %like% "All", "All", NA)))))))]
pdat$age <- factor(pdat$age, levels = c("All", "18-29", "30-39","40-49","50-59","60-69","70+"))

ggplot(pdat, aes(x = age, y = mean, fill = period.lab)) + 
  ggtitle("Mean AUDIT-C sum score by age group - before and during the pandemic",
          "Data collected in Colombia and Mexico") +
  theme_bw() + facet_grid(country ~ sex, scales = "free") +
  geom_bar(stat = "identity", position = position_dodge(1)) +  
  geom_errorbar(aes(ymin = lower, ymax = upper), position = position_dodge(1), width = 0.2) + # #F1BF30
  scale_fill_manual(name = "", values = colors2) + 
  scale_x_discrete(name = "Age group") +
  scale_y_continuous(name = "Mean AUDIT-C sum score") +
  theme(strip.background = element_rect(fill="white"), #axis.text.x = element_text(angle = 45, vjust =0.5, hjust=0.5),
        legend.position = "bottom")
    
ggsave(paste0("outputs/",DATE,"/Figure_2.png"), width = 10, height = 6)
ggsave(paste0("outputs/",DATE,"/Figure_2_1200dpi.tiff"), width = 10, height = 6, dpi = 1200)

# reporting:
checkdat <- dcast(pdat, iso + country + sex + age ~ period, value.var = c("mean","lower","upper"))
checkdat[iso == "COL" & lower_0 > upper_1]
checkdat[iso == "MEX" & lower_0 > upper_1]



# 5.2) FIGURE 3: Mean AUDIT-C by country - sex education and period
# ----------------------------------------------

pdat <- copy(alc.dat[!is.na(auditc.sum) & edu.lab != "not reported" & sex.pat.lab != "other / not reported",.(iso,period,auditc.sum,sex = sex.pat.lab,education = edu.lab)])
pdat[, country := ifelse(iso == "COL", "Colombia", "Mexico")]
pdat$period.lab <- factor(pdat$period, labels = c("0" = "before COVID", "1" = "during COVID"))

add1 <- pdat[, .(.N, education = "All",
                 mean = t.test(auditc.sum)$estimate,
                 lower = t.test(auditc.sum)$conf.int[1],
                 upper = t.test(auditc.sum)$conf.int[2]), by = .(iso,country,period,period.lab,sex)] 
add2 <- pdat[, .(.N, 
                 mean = t.test(auditc.sum)$estimate,
                 lower = t.test(auditc.sum)$conf.int[1],
                 upper = t.test(auditc.sum)$conf.int[2]), by = .(iso,country,period,period.lab,sex,education)]

pdat <- rbind(add1,add2)
pdat$education <- str_wrap(pdat$education, width = 15)
pdat$education <- factor(pdat$education, levels = c("All", "Less than high\nschool", "High school","Any education\nbeyond high\nschool"))


ggplot(pdat, aes(x = education, y = mean, fill = period.lab)) + 
  ggtitle("Mean AUDIT-C sum score by educational achievement - before and during the pandemic",
          "Data collected in Colombia and Mexico") +
  theme_bw() + facet_grid(country ~ sex, scales = "free") +
  geom_bar(stat = "identity", position = position_dodge(1)) +  
  geom_errorbar(aes(ymin = lower, ymax = upper), position = position_dodge(1), width = 0.2) + # #F1BF30
  scale_fill_manual(name = "", values = colors2) + 
  scale_x_discrete(name = "Education") +
  scale_y_continuous(name = "Mean AUDIT-C sum score") +
  theme(strip.background = element_rect(fill="white"), #axis.text.x = element_text(angle = 45, vjust =0.5, hjust=0.5),
        legend.position = "bottom")

ggsave(paste0("outputs/",DATE,"/Figure_3.png"), width = 10, height = 6)
ggsave(paste0("outputs/",DATE,"/Figure_3_1200dpi.tiff"), width = 10, height = 6, dpi = 1200)

# reporting:
checkdat <- dcast(pdat, iso + country + sex + education ~ period, value.var = c("mean","lower","upper"))
checkdat[iso == "COL" & lower_0 > upper_1]
checkdat[iso == "MEX" & lower_0 > upper_1]



# 5.4) FIGURE 4: EACH AUDIT SCORE by country - sex and period
# ----------------------------------------------

pdat <- copy(alc.dat[(!is.na(audit1) | !is.na(audit2) | !is.na(audit3)) & sex.pat.lab != "other / not reported",.(iso,period,audit1,audit2,audit3,sex = sex.pat.lab)])
pdat[, country := ifelse(iso == "COL", "Colombia", "Mexico")]
pdat$period.lab <- factor(pdat$period, labels = c("0" = "before COVID", "1" = "during COVID"))
pdat <- melt(pdat, id.vars = c("iso","country","period","period.lab","sex"))
pdat$var.lab <- factor(pdat$variable, labels = c("audit1" = "1 - Frequency", "audit2" = "2 - Quantity", "audit3" = "3 - Heavy episodic drinking"))

pdat <- pdat[, .(.N,
                 mean = t.test(value)$estimate,
                 lower = t.test(value)$conf.int[1],
                 upper = t.test(value)$conf.int[2]), by = .(iso,country,period,period.lab,sex,variable,var.lab)] 

ggplot(pdat, aes(x = sex, y = mean, fill = period.lab)) + 
  ggtitle("Mean score on each AUDIT-C item - before and during the pandemic",
          "Data collected in Colombia and Mexico") +
  theme_bw() + facet_grid(country ~ var.lab, scales = "free") +
  geom_bar(stat = "identity", position = position_dodge(1)) +  
  geom_errorbar(aes(ymin = lower, ymax = upper), position = position_dodge(1), width = 0.2) + # #F1BF30
  scale_fill_manual(name = "", values = colors2) + 
  scale_x_discrete(name = "") +
  scale_y_continuous(name = "Mean score") +
  theme(strip.background = element_rect(fill="white"),
        legend.position = "bottom")

ggsave(paste0("outputs/",DATE,"/Figure_4.png"), width = 10, height = 6)
ggsave(paste0("outputs/",DATE,"/Figure_4_1200dpi.tiff"), width = 10, height = 6, dpi = 1200)

# reporting:
checkdat <- dcast(pdat, iso + country + sex + variable ~ period, value.var = c("mean","lower","upper"))
checkdat[iso == "COL" & lower_0 > upper_1]
checkdat[iso == "MEX" & lower_0 > upper_1]

# ==================================================================================================================================================================
# ==================================================================================================================================================================
# ==================================================================================================================================================================

# 6) APPENDIX FIGURES
# ______________________________________________________________________________________________________________________



# 6.1) APPENDIX FIGURE 1: Number of alcohol measurements
# ----------------------------------------------

pdat <- copy(day.dat)[order(date.tally)]
pdat[, vertical := ifelse(iso == "COL", covid.col, covid.mex)]

# cumulative number of
pdat[, alc.measured.cum := cumsum(alc.measured), by = iso]

ggplot(pdat, aes(x = date.tally, y = alc.measured.cum)) + 
  theme_bw() + facet_grid(country ~ ., scales = "free") + 
  ggtitle("Cumulative number of AUDIT-C responses",
          "Dashed vertical line indicates begin of COVID-19 pandemic") +
  geom_line(color = c2Panel_b[1], alpha = 1, size = 1) +  
  geom_vline(aes(xintercept = vertical), linetype = 2) +
  scale_x_date(name = "", date_labels = "%b/%Y", date_breaks = "2 months") +
  scale_y_continuous(name = "") +
  theme(axis.text.x = element_text(angle = 45, vjust =0.5, hjust=0.5),
        strip.background = element_rect(fill="white"))

ggsave(paste0("outputs/",DATE,"/Appendix Figure_1.png"), width = 6, height = 5)


# 6.2) FIGURE 2: AUDIT-C profile BY MONTH
# ----------------------------------------------

pdat <- copy(month.dat[variable != "audit.0"])

# normalize:
pdat[, norm := sum(value), by = .(iso, YEAR, MONTH)]
pdat[, value := value / norm]
pdat[, norm := sum(value), by = .(iso, YEAR, MONTH)]

# var label
pdat[, variable := as.numeric(gsub("audit\\.", "", variable ))]
pdat$variable.fac <- factor(pdat$variable, levels = rev(unique(pdat$variable)))

# other
pdat[, vertical := ifelse(YEAR == 2019 | (YEAR == 2020 & MONTH < 3), F, T)]
pdat[, MONTH := as.character(MONTH)]
pdat[, MONTH := ifelse(MONTH %like% "10|11|12", MONTH, paste0("0",MONTH))]
pdat[, TIME := as.numeric(paste0(YEAR,MONTH))]
pdat[, TIME.LAB := paste0(YEAR,"-",MONTH)]
pdat <- pdat[order(TIME)]
pdat$TIME.LAB <- factor(pdat$TIME.LAB, levels = unique(pdat$TIME.LAB), ordered = T)
levels(pdat$TIME.LAB)

# color scale
cc <- scales::seq_gradient_pal("#400014","#F0C1AC")(seq(0,1,length.out = 12))

ggplot(pdat, aes(x = TIME.LAB)) + 
  theme_bw() + facet_grid(country ~ ., scales = "free") + 
  ggtitle("AUDIT-C score distribution") +
  geom_bar(aes(fill = variable.fac, y = value), position = "stack", stat = "identity", alpha = 0.8) +  
  geom_point(aes(y = auditc.sum.median / 4)) +  
  scale_fill_manual(values=cc) +
  scale_x_discrete(name = "") +
  scale_y_continuous(name = "% of patients with respective AUDIT-C sum score", labels = scales::percent,
                     sec.axis = sec_axis(~.*4, name="Median AUDIT-C")) +
  theme(axis.text.x = element_text(angle = 45, vjust =0.5, hjust=0.5),
        legend.title = element_blank(),
        strip.background = element_rect(fill="white"))

ggsave(paste0("outputs/",DATE,"/Appendix Figure_2.png"), width = 8, height = 5)

pdat[iso == "COL" & variable >= 8,.(sum(value)), by = .(TIME.LAB)]
pdat[iso == "MEX" & variable >= 8,.(sum(value)), by = .(TIME.LAB)]

pdat[iso == "COL" & variable == 8,.(auditc.sum.median), by = .(TIME.LAB)]
pdat[iso == "MEX" & variable == 8,.(auditc.sum.median), by = .(TIME.LAB)]

